@@ -1,22 +1,9 @@
-/***************************************************************************
- *   Copyright 2013 Marco Martin <mart@kde.org>                            *
- *   Copyright 2014 Sebastian Kügler <sebas@kde.org>                       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2013 Marco Martin <mart@kde.org>
+    SPDX-FileCopyrightText: 2014 Sebastian Kügler <sebas@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef UNITS_H
 #define UNITS_H
@@ -26,20 +13,22 @@
 
 #include <Plasma/Theme>
 
+#include <KConfigWatcher>
+
 class QQuickItem;
 
 class SharedAppFilter : public QObject
 {
-   Q_OBJECT
+    Q_OBJECT
 public:
-    SharedAppFilter(QObject *parent = 0);
-    ~SharedAppFilter();
+    explicit SharedAppFilter(QObject *parent = nullptr);
+    ~SharedAppFilter() override;
 
 Q_SIGNALS:
     void fontChanged();
 
 protected:
-    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *watched, QEvent *event) override;
 };
 
 /**
@@ -52,8 +41,8 @@ class Units : public QObject
 
     /**
      * The fundamental unit of space that should be used for sizes, expressed in pixels.
-     * Given the screen has an accurate DPI settings, it corresponds to a width of
-     * the capital letter M
+     * Given the screen has an accurate DPI settings, it corresponds to the height of
+     * the font's boundingRect.
      */
     Q_PROPERTY(int gridUnit READ gridUnit NOTIFY gridUnitChanged)
 
@@ -73,8 +62,8 @@ class Units : public QObject
      * * desktop (DEPRECATED: use iconSizeHints instead)
      *
      */
-    //note the iconSizeChanged signal indicates that one (or more) of these icons have changed
-    //but the property map itself remains constant
+    // note the iconSizeChanged signal indicates that one (or more) of these icons have changed
+    // but the property map itself remains constant
     Q_PROPERTY(QQmlPropertyMap *iconSizes READ iconSizes CONSTANT)
 
     /**
@@ -88,8 +77,8 @@ class Units : public QObject
      * * panel
      * * desktop
      */
-    //note the iconSizeHintsChanged signal indicates that one (or more) of these icons have changed
-    //but the property map itself remains constant
+    // note the iconSizeHintsChanged signal indicates that one (or more) of these icons have changed
+    // but the property map itself remains constant
     Q_PROPERTY(QQmlPropertyMap *iconSizeHints READ iconSizeHints CONSTANT)
 
     // layout hints
@@ -113,7 +102,7 @@ class Units : public QObject
     /**
      * The ratio between physical and device-independent pixels. This value does not depend on the \
      * size of the configured font. If you want to take font sizes into account when scaling elements,
-     * use theme.mSize(theme.defaultFont), units.smallSpacing and units.largeSpacing.
+     * use PlasmaCore.Theme.mSize(PlasmaCore.Theme.defaultFont), PlasmaCore.Units.smallSpacing and PlasmaCore.Units.largeSpacing.
      * The devicePixelRatio follows the definition of "device independent pixel" by Microsoft.
      */
     Q_PROPERTY(qreal devicePixelRatio READ devicePixelRatio NOTIFY devicePixelRatioChanged)
@@ -130,8 +119,50 @@ class Units : public QObject
      */
     Q_PROPERTY(int shortDuration READ shortDuration NOTIFY durationChanged)
 
+    /**
+     * units.veryShortDuration should be used for elements that should animate near instantly,
+     * but should have a hint of smoothness
+     */
+    Q_PROPERTY(int veryShortDuration READ veryShortDuration NOTIFY durationChanged)
+
+    /**
+     * units.veryLongDuration should be used for specialty animations that benefit
+     * from being even longer than longDuration.
+     */
+    Q_PROPERTY(int veryLongDuration READ veryLongDuration NOTIFY durationChanged)
+
+    /**
+     * Time in milliseconds equivalent to the theoretical human moment, which can be used
+     * to determine whether how long to wait until the user should be informed of something,
+     * or can be used as the limit for how long something should wait before being
+     * automatically initiated.
+     *
+     * Some examples:
+     *
+     * - When the user types text in a search field, wait no longer than this duration after
+     *   the user completes typing before starting the search
+     * - When loading data which would commonly arrive rapidly enough to not require interaction,
+     *   wait this long before showing a spinner
+     *
+     * This might seem an arbitrary number, but given the psychological effect that three
+     * seconds seems to be what humans consider a moment (and in the case of waiting for
+     * something to happen, a moment is that time when you think "this is taking a bit long,
+     * isn't it?"), the idea is to postpone for just before such a conceptual moment. The reason
+     * for the two seconds, rather than three, is to function as a middle ground: Not long enough
+     * that the user would think that something has taken too long, for also not so fast as to
+     * happen too soon.
+     *
+     * See also
+     * https://www.psychologytoday.com/blog/all-about-addiction/201101/tick-tock-tick-hugs-and-life-in-3-second-intervals
+     * (the actual paper is hidden behind an academic paywall and consequently not readily
+     * available to us, so the source will have to be the blog entry above)
+     *
+     * @since 5.81
+     */
+    Q_PROPERTY(int humanMoment READ humanMoment CONSTANT)
+
 public:
-/// @cond INTERNAL_DOCS
+    /// @cond INTERNAL_DOCS
 
     ~Units();
 
@@ -185,7 +216,25 @@ public:
      * @since 5.0
      */
     int shortDuration() const;
-/// @endcond
+
+    /**
+     * @return Duration for very long animations, in milliseconds.
+     * @since 5.69
+     */
+    int veryLongDuration() const;
+
+    /**
+     * @return Duration for instantaneous animations, in milliseconds.
+     * @since 5.78
+     */
+    int veryShortDuration() const;
+
+    /**
+     * @return Duration for very long wait times
+     * @since 5.81
+     */
+    int humanMoment() const;
+    /// @endcond
 
     /**
      * @return a size rounded tothe nearest inferior standard icon size.
@@ -205,18 +254,17 @@ Q_SIGNALS:
 
 private Q_SLOTS:
     void iconLoaderSettingsChanged();
-    void settingsFileChanged(const QString &file);
     void updateSpacing();
 
 private:
-    Units(QObject *parent = 0);
-    Units(Units const&) = delete; // Copy construct
-    Units(Units&&) = delete; // Move construct
-    Units& operator=(Units const&) = delete; // Copy assign
-    Units& operator=(Units &&) = delete; // Move assign
+    Units(QObject *parent = nullptr);
+    Units(Units const &) = delete; // Copy construct
+    Units(Units &&) = delete; // Move construct
+    Units &operator=(Units const &) = delete; // Copy assign
+    Units &operator=(Units &&) = delete; // Move assign
 
     void updateDevicePixelRatio();
-    void updatePlasmaRCSettings();
+    void updateAnimationSpeed();
     /**
      * @return The dpi-adjusted size for a given icon size
      */
@@ -232,8 +280,8 @@ private:
     int m_smallSpacing;
     int m_largeSpacing;
 
+    KConfigWatcher::Ptr m_animationSpeedWatcher;
     int m_longDuration;
 };
 
-#endif //UNITS_H
-
+#endif // UNITS_H
