@@ -1,42 +1,28 @@
-/******************************************************************************
-*   Copyright 2007-2009 by Aaron Seigo <aseigo@kde.org>                       *
-*                                                                             *
-*   This library is free software; you can redistribute it and/or             *
-*   modify it under the terms of the GNU Library General Public               *
-*   License as published by the Free Software Foundation; either              *
-*   version 2 of the License, or (at your option) any later version.          *
-*                                                                             *
-*   This library is distributed in the hope that it will be useful,           *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU          *
-*   Library General Public License for more details.                          *
-*                                                                             *
-*   You should have received a copy of the GNU Library General Public License *
-*   along with this library; see the file COPYING.LIB.  If not, write to      *
-*   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
-*   Boston, MA 02110-1301, USA.                                               *
-*******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007-2009 Aaron Seigo <aseigo@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
-#include <math.h>
 #include <float.h> // FLT_MAX
+#include <math.h>
 
 #include <QCoreApplication>
-#include <QFileInfo>
 #include <QDebug>
+#include <QFileInfo>
 
-#include <kconfiggroup.h>
-#include <kdesktopfile.h>
-#include <klocalizedstring.h>
+#include <KConfigGroup>
+#include <KDesktopFile>
+#include <KLocalizedString>
 
-#include <kdeclarative/kdeclarative.h>
-#include "packages_p.h"
 #include "config-plasma.h"
+#include "packages_p.h"
+#include <kdeclarative/kdeclarative.h>
 
 #include <kpackage/package.h>
 
 namespace Plasma
 {
-
 void ChangeableMainScriptPackage::initPackage(KPackage::Package *package)
 {
     package->addFileDefinition("mainscript", QStringLiteral("ui/main.qml"), i18n("Main Script File"));
@@ -107,4 +93,3 @@ void GenericPackage::initPackage(KPackage::Package *package)
 }
 
 } // namespace Plasma
-
